@@ -4,8 +4,10 @@ import requests
 from pagador import settings
 
 
-def grava_evidencia_retorno(meio_pagamento, dados, tipo_evidencia="pagador-retorno", registrado=False, enviado=None):
+def grava_evidencia_retorno(meio_pagamento, dados, conta_id, pedido_numero, tipo_evidencia="pagador-retorno", registrado=False, enviado=None):
     evidencia = {
+        "conta_id": conta_id,
+        "pedido_numero": pedido_numero,
         "tipo_evidencia": tipo_evidencia,
         "evidencia": {
             "meio_pagamento": meio_pagamento,
