@@ -57,13 +57,13 @@ class RegistroBase(object):
 
 
 class RegistrarPagamento(Plugavel):
-    def __init__(self, meio_pagamento, dados, tipo="retorno", configuracao_pagamento=None):
-        self.meio_pagamento = meio_pagamento
+    def __init__(self, dados, configuracao_pagamento, tipo="retorno"):
+        self.meio_pagamento = configuracao_pagamento.meio_pagamento
+        self.configuracao_pagamento = configuracao_pagamento
         self.dados = dados
         self._registrador = None
         self._conta_id = None
         self.tipo = tipo
-        self.configuracao_pagamento = configuracao_pagamento
 
     @property
     def registrador(self):
