@@ -19,6 +19,10 @@ EVIDENCIA_URL = config.EVIDENCIA_URL
 EVIDENCIA_USA_AUTENTICACAO_HEADER = config.EVIDENCIA_USA_AUTENTICACAO_HEADER
 EVIDENCIA_HEADER_AUTENTICACAO = config.EVIDENCIA_HEADER_AUTENTICACAO
 MODULO_PARAMETROS_INSTALACAO = config.MODULO_PARAMETROS_INSTALACAO
+try:
+    DIRETORIOS_DOS_TEMPLATES = config.DIRETORIOS_DOS_TEMPLATES
+except AttributeError:
+    pass
 
 MERCADOPAGO_REDIRECT_URL = config.MERCADOPAGO_REDIRECT_URL
 MERCADOPAGO_PREFERENCE_NOTIFICATION_URL = config.MERCADOPAGO_PREFERENCE_NOTIFICATION_URL
